@@ -1,4 +1,4 @@
-#!/bin/bash
+#!/usr/pkg/bin/bash
 #
 # NetSurf continuous integration build script for jenkins
 #
@@ -32,6 +32,7 @@
 # static - perform a static analysis
 # coverity - perform a coverity scan
 # docs - build doxygen docs
+# sanitize - Run the test suite under ASAN and UBSAN
 
 # HOST must be in the environment and set correctly
 if [ "x${HOST}" = "x" ];then
@@ -100,6 +101,11 @@ case "$1" in
 	TARGET_DOCS=${HOST}
 	;;
 
+    "sanitize")
+	TARGET_SANITIZE=${HOST}
+	VARIANT="debug"
+	;;
+
     "")
 	# default is test only on Linux and install
 	# Currently most tests do not work on targets except for Linux
@@ -109,7 +115,7 @@ case "$1" in
 
     *)
 	cat <<EOF
-Usage: jenkins-build.sh [install|test-install|coverage|static|docs]
+Usage: jenkins-build.sh [install|test-install|coverage|static|docs|sanitize]
 
        install        build and install
        test-install   build, test and install
@@ -117,6 +123,7 @@ Usage: jenkins-build.sh [install|test-install|coverage|static|docs]
        static         perform a static anaysis
        coverity       perform a coverity scan
        docs           generate doxygen docs
+       sanitize       run the tests under ASAN/UBSAN
 EOF
 	exit 1
 	;;
@@ -130,10 +137,19 @@ case ${BUILD} in
 	MAKE=gmake
 	;;
 
+    x86_64-unknown-openbsd*)
+	MAKE=gmake
+	;;
+
     x86_64-unknown-freebsd*)
 	MAKE=gmake
 	;;    
 
+    x86_64-apple-darwin14.5.0*)
+        PATH="/opt/local/bin:/opt/local/sbin:$PATH"
+	MAKE=make
+        ;;
+
     *)
 	MAKE=make
 	;;
@@ -161,8 +177,7 @@ ${MAKE} Q= clean HOST=${HOST} VARIANT=${VARIANT}
 if [ "x${HOST}" = "x${TARGET_COVERAGE}" ]; then
     # Coverage Build
     CFLAGS=-Wno-error ${MAKE} Q= HOST=${HOST} VARIANT=${VARIANT} coverage
-    gcovr -x -r build-${BUILD}-${HOST}-${VARIANT}-lib-static -o coverage.xml
-
+    gcovr -v -x -e 'test/.*' -r . -o coverage.xml
 
 elif [ "x${HOST}" = "x${TARGET_STATIC}" ]; then
     # static build
@@ -212,6 +227,9 @@ elif [ "x${HOST}" = "x${TARGET_DOCS}" ]; then
     # Documentation build
     ${MAKE} Q= HOST=${HOST} VARIANT=${VARIANT} docs
 
+elif [ "x${HOST}" = "x${TARGET_SANITIZE}" ]; then
+    # Sanitize build
+    env UBSAN_OPTIONS=print_stacktrace=1 ${MAKE} Q= HOST=${HOST} VARIANT=${VARIANT} sanitize
 
 else
     # Normal build
